% RCS reduction analysis using dipoles

clc; 
clear all;
format long;            % prints out more digits
format compact;         % makes the output more compact

% Constants
lambda0 = 54.5/1000;  % in meters
L = lambda0/2;      % length of dipole
f = 5.5e9;
c = 299792458;
mu0 = 4*pi*(1e-7);
eps0 = 1/mu0/(c^2);
omg = 2*pi*f;
k0 = omg*sqrt(mu0*eps0);

% Currents (in Ampere)
Ampl = 0.25;
phase = 189.23;  % in degrees
I1 = Ampl*(cos(phase*pi/180)+1i*sin(phase*pi/180));
I2 = -Ampl*(cos(phase*pi/180)+1i*sin(phase*pi/180));
I3 = -1;

% Coordinates - x,y,z
x0 = 1.92;
y0 = -2:0.01:2;
z0 = -2:0.01:2;

x1 = lambda0/4;
y1 = 0;
z1 = 0;

x2 = -lambda0/4;
y2 = 0;
z2 = 0;

x3 = -1.92;
y3 = 0;
z3 = 0;

for ii = 1:length(z0)
  for jj = 1:length(y0)

    % Coordinates - Spherical
    R1 = sqrt((x0-x1)^2 + y0(jj)^2 + z0(ii)^2);
    th1 = acos(z0(ii)/R1);
    ph1 = atan(y0(jj)/(x0-x1));
    
    R2 = sqrt((x0-x2)^2 + y0(jj)^2 + z0(ii)^2);
    th2 = acos(z0(ii)/R2);
    ph2 = atan(y0(jj)/(x0-x2));
    
    R3 = sqrt((x0-x3)^2 + y0(jj)^2 + z0(ii)^2);
    th3 = acos(z0(ii)/R3);
    ph3 = atan(y0(jj)/(x0-x3));
    
    % Array Factor for a finite length dipole
    a1 = (2*I1/sin(k0*L/2))*(cos(0.5*k0*L*cos(th1))-cos(0.5*k0*L))/(k0*sin(th1)*sin(th1));
    a2 = (2*I2/sin(k0*L/2))*(cos(0.5*k0*L*cos(th2))-cos(0.5*k0*L))/(k0*sin(th2)*sin(th2));
    a3 = (2*I3/sin(k0*L/2))*(cos(0.5*k0*L*cos(th3))-cos(0.5*k0*L))/(k0*sin(th3)*sin(th3));
    
    % Array Factor for a infinitesimal dipole
    %a1 = I1;
    %a2 = I2;
    %a3 = I3;

    % Fields
    E_th1 = a1*(1i*omg*mu0/(4*pi))*(exp(-1i*k0*R1)/R1)*sin(th1);
    E_th2 = a2*(1i*omg*mu0/(4*pi))*(exp(-1i*k0*R2)/R2)*sin(th2);
    E_th3 = a3*(1i*omg*mu0/(4*pi))*(exp(-1i*k0*R3)/R3)*sin(th3);
    
    E_z1 = -E_th1*sin(th1);
    E_x1 = E_th1*cos(th1)*cos(ph1);
    E_y1 = E_th1*cos(th1)*sin(ph1);
    
    E_z2 = -E_th2*sin(th2);
    E_x2 = E_th2*cos(th2)*cos(ph2);
    E_y2 = E_th2*cos(th2)*sin(ph2);
    
    E_z3 = -E_th3*sin(th3);
    E_x3 = E_th3*cos(th3)*cos(ph3);
    E_y3 = E_th3*cos(th3)*sin(ph3);
    
    E_x = E_x1 + E_x2 + E_x3;
    E_y = E_y1 + E_y2 + E_y3;
    E_z = E_z1 + E_z2 + E_z3;
    
    E_tot(ii,jj) = sqrt(E_x^2 + E_y^2 + E_z^2);
  end
end

%disp(abs(E_tot((length(z0)+1)*0.5,(length(y0)+1)*0.5)))

%E_n = 8.999353955595764e+02;   % for infinitesimal dipole
E_n = 15.610717;

figure(1)
contourf(z0,y0,abs(E_tot)./E_n,10)
colorbar
xlabel('\ity\rm in m')
ylabel('\itx\rm in m')         % actually z axis in this case
title('\itz\rm = 1.92 m')         % z is the x axis

figure(2)
plot(y0,20*log10(abs(E_tot((length(z0)+1)*0.5,:))./E_n),'LineWidth',2)      %15.610717
xlabel('\ity\rm in m')
ylabel('Normalized \itE_t_o_t_a_l\rm in dB')
title('\itz\rm = 1.92 m, \itx\rm = 0')      % z is the x axis

figure(3)
plot(z0,20*log10(abs(E_tot(:,(length(y0)+1)*0.5))./E_n),'LineWidth',2)
xlabel('\itx\rm in m')         % actually z axis in this case
ylabel('Normalized \itE_t_o_t_a_l\rm in dB')
title('\itz\rm = 1.92 m, \ity\rm = 0')      % z is the x axis
