% RCS reduction analysis using 1 defending dipole close to a finite tilted PEC plate
% with plane wave incidence

clc; 
clear all;
format long;            % prints out more digits
format compact;         % makes the output more compact

% Constants
lambda0 = 54.5/1000;  % in meters
L = lambda0/2;      % length of dipole
Lp = 0.6096;     % length of the finite plate
f = 5.5e9;
c = 299792458;
mu0 = 4*pi*(1e-7);
eps0 = 1/mu0/(c^2);
omg = 2*pi*f;
k0 = omg*sqrt(mu0*eps0);
R = 50;    % in meters
h = lambda0/4;

% Currents (in Ampere)
Ampl = 0.25;
phase = 189.23;  % in degrees
I1 = Ampl*(cos(phase*pi/180)+1i*sin(phase*pi/180));
I2 = -Ampl*(cos(phase*pi/180)+1i*sin(phase*pi/180));
I3 = -1;

phi = (-90:0.01:90).*(pi/180);
theta = (0:0.01:180).*(pi/180);
P = length(phi);
T = length(theta);
ph_pw = 90*pi/180;
th_pw = 30*pi/180;

for ii = 1:T
  for jj = 1:P

    % Coordinates - Spherical
    th = theta(ii);
    ph = phi(jj);
    
    % Array Factor for the Plate
    aP = (Lp^2/4).*sinc(0.5.*Lp.*k0.*(sin(th_pw).*sin(ph_pw)+sin(th).*sin(ph))) ......
         .*sinc(0.5.*Lp.*k0.*(cos(th_pw)+cos(th))).*sin(th_pw);
    
    % Scattered Fields from the Plate
    Es_z = aP.*sin(th).*(exp(-1i*k0*R)/R);
    
    if ((th == th_pw)&&(ph == ph_pw))
        E_n = Es_z;
    end
        
    % Array Factor for a finite length dipole
    Rd = sqrt((R*sin(th)*cos(ph)-h)^2 + (R*sin(th)*sin(ph))^2 + (R*cos(th))^2);
    I0 = -sinc(k0.*Lp.*sin(th_pw).*sin(ph_pw)).*sinc(k0.*Lp.*cos(th_pw)) .....
        .*sin(th_pw).*sin(th_pw).*exp(-1i*k0*(R-Rd)).*(Rd/R).*k0.*sin(k0*L/2) ......
        ./((omg*mu0/pi).*sin(k0.*h.*cos(ph_pw).*sin(th_pw)).*(cos((k0*L/2).*cos(th_pw))-cos(k0*L/2)));
    aF = (2*I0/sin(k0*L/2))*(cos(0.5*k0*L*cos(th))-cos(0.5*k0*L))/(k0*sin(th)*sin(th));
    
    % Array Factor for a infinitesimal dipole
    %aF = I0;

    % Fields due to the dipole and its image (approximate)
    Ed_th = aF*(1i*omg*mu0/(4*pi))*(exp(-1i*k0*Rd)/Rd)*sin(th)*(2*1i*sin(k0*h*cos(ph)*sin(th)));
    
    Ed_z = -Ed_th*sin(th);
    Ed_x = Ed_th*cos(th)*cos(ph);
    Ed_y = Ed_th*cos(th)*sin(ph);
    
    E_x = Ed_x;
    E_y = Ed_y;
    E_z = Ed_z + Es_z;
    
    E_tot(ii,jj) = sqrt(E_x^2 + E_y^2 + E_z^2);
  end
end

%disp(abs(E_tot((length(z0)+1)*0.5,(length(y0)+1)*0.5)))

%E_n = abs(exp(-1i*k0*R)/R);

% figure(1)
% contourf(z0,y0,abs(E_tot)./E_n,10)
% colorbar
% xlabel('\ity\rm in m')
% ylabel('\itx\rm in m')         % actually z axis in this case
% title('\itz\rm = 1.92 m')         % z is the x axis

figure(1)
plot(theta.*180./pi,20*log10(abs(E_tot(:,0.5*(P+1)))./E_n),'LineWidth',2)      %15.610717
xlabel('\it\theta\rm in degrees')
ylabel('Normalized \itE_t_o_t_a_l\rm in dB')
title('\itx\rm = 50 m, E plane (\it\phi\rm = 0^o)')
axis([0 180 -90 40])

figure(2)
plot(phi.*180./pi,20*log10(abs(E_tot(0.5*(T+1),:))./E_n),'LineWidth',2)
xlabel('\it\phi\rm in degrees')         
ylabel('Normalized \itE_t_o_t_a_l\rm in dB')
title('\itx\rm = 50 m, H plane (\it\theta\rm = 90^o)')      
axis([-90 90 -90 40])
